package com.yiqi.recharge.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.recharge.domain.RechargeType;

/**
 * 充值规则管理Service接口
 *
 * @author xiaohei
 * @date 2023-08-28
 */
public interface IRechargeTypeService extends IService<RechargeType> {
    /**
     * 查询充值规则管理
     *
     * @param id 充值规则管理主键
     * @return 充值规则管理
     */
    public RechargeType selectRechargeTypeById(Long id);

    /**
     * 查询充值规则管理列表
     *
     * @param rechargeType 充值规则管理
     * @return 充值规则管理集合
     */
    public List<RechargeType> selectRechargeTypeList(RechargeType rechargeType);

    /**
     * 新增充值规则管理
     *
     * @param rechargeType 充值规则管理
     * @return 结果
     */
    public int insertRechargeType(RechargeType rechargeType);

    /**
     * 修改充值规则管理
     *
     * @param rechargeType 充值规则管理
     * @return 结果
     */
    public int updateRechargeType(RechargeType rechargeType);

    /**
     * 批量删除充值规则管理
     *
     * @param ids 需要删除的充值规则管理主键集合
     * @return 结果
     */
    public int deleteRechargeTypeByIds(Long[] ids);

    /**
     * 删除充值规则管理信息
     *
     * @param id 充值规则管理主键
     * @return 结果
     */
    public int deleteRechargeTypeById(Long id);


    /**
     * 修改充值规则管理状态
     *
     * @param rechargeType 充值规则管理
     * @return 结果
     */
    public int updateRechargeTypeStatus(RechargeType rechargeType);

}
